Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrTaskNotFound = errors.New("task not found") ErrTaskAlreadyExists = errors.New("task already exists") )
Functions ¶
This section is empty.
Types ¶
type Task ¶
Task represents a task that may need to be performed. It is purely a domain entity with no context of usecases or applications.
type TaskRepository ¶
type TaskRepository interface {
Insert(context.Context, *Task) error
FindAll(context.Context) ([]Task, error)
FindByID(ctx context.Context, id int64) (*Task, error)
Update(context.Context, *Task) error
DeleteByID(ctx context.Context, id int64) error
}
TaskRepository is the interface used to persist the Task(s).
Click to show internal directories.
Click to hide internal directories.